# Fibo Sum

## A Python package with the sole function of giving you the sum of N fibonacci terms.

### _Beware the golden ration complexity_

## Install

```shell
pip install fibo-sum
```    

## Usage

```python
from fibo_sum.fibo_sum import fibo_sum

print(fibo_sum(13))
```